package org.objectweb.telosys.uil;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;

import org.objectweb.telosys.common.TelosysObject;
import org.objectweb.telosys.screen.core.ScreenContext;
import org.objectweb.telosys.screen.core.ScreenData;
import org.objectweb.telosys.screen.env.ScreenSession;

/**
 * The Telosys request environment. <br>
 * The 'request ecosystem' for an 'action request' or a 'service request' <br>
 * Provides the standard servlet objects ( ServletContext, HttpSession, HttpServletRequest )<br>
 * And provides the telosys objects ( ScreenApplication, ScreenSession, ScreenContext )<br>
 * NB: the ScreenContext is available only for an 'action request'
 * 
 * @author Laurent GUERIN
 *  
 */
public class RequestEnv extends TelosysObject
{
    private static final String TELOSYS_REQUEST_ENV = "TELOSYS_REQUEST_ENV";

    //HttpServletRequest          _httpServletRequest = null;

    //HttpSession                 _httpSession        = null;

    //ServletContext              _servletContext     = null;

    //ScreenSession               _screenSession      = null;

    //ScreenApplication           _screenApplication  = null;

    ScreenContext               _screenContext      = null;

    //-----------------------------------------------------------------------------------------
    public static void setEnv(HttpServletRequest httpServletRequest, ScreenSession screenSession)
    {
        //setEnv(httpServletRequest, new RequestEnv(httpServletRequest, screenSession));
        setEnv(httpServletRequest, new RequestEnv(httpServletRequest));
    }

    //-----------------------------------------------------------------------------------------
    //public static void setEnv(HttpServletRequest httpServletRequest, ScreenSession screenSession, ScreenContext screenContext)
    public static void setEnv(HttpServletRequest httpServletRequest, ScreenContext screenContext)
    {
        //setEnv(httpServletRequest, new RequestEnv(httpServletRequest, screenSession, screenContext));
        setEnv(httpServletRequest, new RequestEnv(httpServletRequest, screenContext));
    }

    //-----------------------------------------------------------------------------------------
    private static void setEnv(HttpServletRequest httpServletRequest, RequestEnv requestEnv)
    {
        httpServletRequest.setAttribute(TELOSYS_REQUEST_ENV, requestEnv);
    }

    //-----------------------------------------------------------------------------------------
    public static RequestEnv getEnv(ServletRequest servletRequest)
    {
        Object obj = servletRequest.getAttribute(TELOSYS_REQUEST_ENV);
        if (obj != null)
        {
            if (obj instanceof RequestEnv)
            {
                return (RequestEnv) obj;
            }
        }
        return null;
    }

    //-----------------------------------------------------------------------------------------

//    private void initEnvironment(HttpServletRequest httpServletRequest, ScreenSession screenSession, ScreenContext screenContext)
    private void initEnvironment(HttpServletRequest httpServletRequest, ScreenContext screenContext)
    {
        //--- Standard servlet objects
//        _httpServletRequest = httpServletRequest;
//        if (_httpServletRequest != null)
//        {
//            _httpSession = _httpServletRequest.getSession(false);
//        }
//        else
//        {
//            _httpSession = null;
//        }
//        if (_httpSession != null)
//        {
//            _servletContext = _httpSession.getServletContext();
//        }
//        else
//        {
//            _servletContext = null;
//        }

        //--- Telosys objects
//        if (screenSession != null)
//        {
//            _screenSession = screenSession;
//            //_screenApplication = screenSession.getScreenApplication();
//        }
        _screenContext = screenContext;

        //--- Expose as a request attribute
        httpServletRequest.setAttribute(TELOSYS_REQUEST_ENV, this);

    }

    //-----------------------------------------------------------------------------------------
    // Private constructors ( no public constructor )
    //-----------------------------------------------------------------------------------------
    private RequestEnv()
    {
    }

//    private RequestEnv(HttpServletRequest httpServletRequest, ScreenSession screenSession)
    private RequestEnv(HttpServletRequest httpServletRequest)
    {
        //initEnvironment(httpServletRequest, screenSession, null);
        initEnvironment(httpServletRequest, null);
    }

//    private RequestEnv(HttpServletRequest httpServletRequest, ScreenSession screenSession, ScreenContext screenContext)
    private RequestEnv(HttpServletRequest httpServletRequest, ScreenContext screenContext)
    {
        //initEnvironment(httpServletRequest, screenSession, screenContext);
        initEnvironment(httpServletRequest, screenContext);
    }

    //----------------------------------------------------------------
    // Standard Servlet objects 
    // removed in v 0.9.9
    //----------------------------------------------------------------
//    public HttpServletRequest getHttpRequest()
//    {
//        return _httpServletRequest;
//    }

//    public HttpSession getHttpSession()
//    {
//        return _httpSession;
//    }

//    public ServletContext getServletContext()
//    {
//        return _servletContext;
//    }

    //----------------------------------------------------------------
    // Telosys objects
    //----------------------------------------------------------------
// removed in v 0.9.9
//    /**
//     * Returns the current ScreenApplication 
//     * @return
//     */
//    public ScreenApplication getScreenApplication()
//    {
//        return _screenApplication;
//    }

    //----------------------------------------------------------------
//  removed in v 0.9.9
//    /**
//     * Returns the ScreenSession associated with the current request
//     * @return
//     */
//    public ScreenSession getScreenSession()
//    {
//        return _screenSession;
//    }

    //----------------------------------------------------------------
    /**
     * Returns the ScreenContext associated with the current ScreenAction request
     * @return the ScreenContext (or null if the current request is not a ScreenAction )
     */
    public ScreenContext getScreenContext()
    {
        return _screenContext;
    }

    //----------------------------------------------------------------
    /**
     * Returns the ScreenData of the ScreenContext associated with the current ScreenAction request
     * @return the ScreenData (or null if the current request is not a ScreenAction )
     */
    public ScreenData getScreenData()
    {
        ScreenData data = null ;
        if (_screenContext != null)
        {
            data = _screenContext.getCurrentData();
        }
        trace("getScreenData() : " + ( data != null ? "NOT NULL" : "NULL" ) );
        return data;
    }

    //----------------------------------------------------------------

}