package org.objectweb.telosys.util;

import java.text.SimpleDateFormat;
import java.util.Calendar;

/**
 * @author Laurent GUERIN
 *  
 */
public final class DateUtil
{

    private final static SimpleDateFormat DATE_ISO_FORMAT   = new SimpleDateFormat("yyyy-MM-dd");

    private final static SimpleDateFormat DATE_TIME_ISO_FORMAT   = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    private final static SimpleDateFormat TIME_ISO_FORMAT   = new SimpleDateFormat("HH:mm:ss");
        
    /** */
    private DateUtil()
    {
    }

    /**
     * 
     * @return java.sql.Date :
     */
    public static java.sql.Date todaySqlDate()
    {
        //--- Date du jour
        return new java.sql.Date(Calendar.getInstance().getTimeInMillis());
    }

    /**
     * 
     * @return java.util.Date :
     */
    public static java.util.Date todayUtilDate()
    {
        //--- Date du jour
        return new java.util.Date(Calendar.getInstance().getTimeInMillis());
    }

    /**
     * 
     * @param sFormat :
     * @return String :
     */
    public static String todayString(final String sFormat)
    {
        //--- Date du jour
        java.util.Date date = new java.util.Date(Calendar.getInstance().getTimeInMillis());
        SimpleDateFormat dateFormat = new SimpleDateFormat(sFormat);
        return dateFormat.format(date);
    }

    /**
     * @param iJ :
     * @param iM :
     * @param iA :
     * @param sFormat : format string usable to build a SimpleDateFormat
     * @return : the formated date ( using the given format )
     */
    public static String format(final int iJ, final int iM, final int iA, final String sFormat)
    {
        java.util.Date date = getUtilDate(iJ, iM, iA);
        SimpleDateFormat dateFormat = new SimpleDateFormat(sFormat);
        return dateFormat.format(date);
    }

    /**
     * @param iDay :
     * @param iMonth :
     * @param iYear :
     * @return : the formated date ( using the default ISO format )
     */
    public static String format(final int iDay, final int iMonth, final int iYear)
    {
        return DATE_ISO_FORMAT.format( getUtilDate(iDay, iMonth, iYear) );
    }

    /**
     * Returns a java.sql.Date instance for the given day, month and year
     * @param iDay :
     * @param iMonth :
     * @param iYear :
     * @return java.sql.Date :
     */
    public static java.sql.Date getSqlDate(final int iDay, final int iMonth, final int iYear)
    {
        Calendar cal = Calendar.getInstance();
        cal.set(iYear, iMonth - 1, iDay);
        return new java.sql.Date(cal.getTimeInMillis());
    }

    /**
     * Returns a standard Date instance for the given day, month and year
     * @param iDay : 1 to 31
     * @param iMonth : 1 to 12
     * @param iYear : 
     * @return java.util.Date :
     */
    public static java.util.Date getUtilDate(final int iDay, final int iMonth, final int iYear)
    {
        Calendar cal = Calendar.getInstance();
        cal.set(iYear, iMonth - 1, iDay);
        return new java.util.Date(cal.getTimeInMillis());
    }

    /**
     * Returns the day of the month for the given date 
     * @param date :
     * @return int : 0 to 31 
     */
    public static int getDay(final java.sql.Date date)
    {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        return cal.get(Calendar.DAY_OF_MONTH);
    }

    /**
     * Returns the month of the given date
     * @param date :
     * @return int : 1 to 12
     */
    public static int getMonth(final java.sql.Date date)
    {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        return cal.get(Calendar.MONTH) + 1;
    }

    /**
     * Returns the year of the given date 
     * @param date :
     * @return int :
     */
    public static int getYear(final java.sql.Date date)
    {
        Calendar cal = Calendar.getInstance();
        cal.setTime(date);
        return cal.get(Calendar.YEAR);
    }

    /**
     * Returns the given date as an ISO date string ( "YYYY-MM-DD" )
     * @param date
     * @return the date in ISO string format ( or "" if null )
     */
    public static String dateISO(final java.util.Date date)
    {
        if (date != null)
        {
            return DATE_ISO_FORMAT.format( date );

        }
        else
        {
            return "";
        }
    }
    
    /**
     * Returns the given date as an ISO time string ( "HH:MM:SS" )
     * @param date
     * @return the time in ISO string format ( or "" if null )
     */
    public static String timeISO(final java.util.Date date)
    {
        if (date != null)
        {
            return TIME_ISO_FORMAT.format( date );

        }
        else
        {
            return "";
        }
    }
    
    /**
     * Returns the given date as an ISO date and time string ( "YYYY-MM-DD HH:MM:SS" )
     * @param date
     * @return the date and time in ISO string format ( or "" if null )
     */
    public static String dateTimeISO(final java.util.Date date)
    {
        if (date != null)
        {
            return DATE_TIME_ISO_FORMAT.format( date );

        }
        else
        {
            return "";
        }
    }

}